--[[

	---------------------------------------------
	GidHelix
	a simple game made to test and learn 
	Gideros SDK Power and Lua coding.
	
	Coded By Gianluca D'Angelo Copyright (C) 2012
	contact: gregbug@gmail.com
	THIS PROGRAM IS FREEWARE
	
	L'Aquila, 15 Gennaio 2012
	---------------------------------------------
	MODULE: Evil bird class
	---------------------------------------------
	OK
--]]

---------------------
-- Evil bird class --
---------------------
birds = gideros.class(Sprite)

local maxSpeed = 100
local minSpeed = 0.5

----------------------------------------------
-- [[ release a random direction -1 or 1 ]] --
----------------------------------------------
function birds:randomDirection()
	local ndirection = math.random(-1, 1)
	while ndirection == 0 do
		ndirection = math.random(-1, 1)
	end
	return ndirection
end

------------------------------
-- [[ init bird class... ]] --
------------------------------
function birds:init(createBody, BirdsToCreate)
	self.bird_body = nil
	self.xSpeed = (math.random(0, maxSpeed)/100)+minSpeed * self.randomDirection()
	self.ySpeed = (math.random(0, maxSpeed)/100)+minSpeed * self.randomDirection()

	-- [[ setup animations... ]] --
	self.anim = {
		Bitmap.new(ingameGFX:getTextureRegion("ucello1.png")),
		Bitmap.new(ingameGFX:getTextureRegion("ucello2.png")),
		Bitmap.new(ingameGFX:getTextureRegion("ucello3.png")),
		Bitmap.new(ingameGFX:getTextureRegion("ucello4.png")),
	}

	self.anim[1]:setAnchorPoint(0.5, 0.5)
	self.anim[2]:setAnchorPoint(0.5, 0.5)
	self.anim[3]:setAnchorPoint(0.5, 0.5)
	self.anim[4]:setAnchorPoint(0.5, 0.5)

	self.Animation = MovieClip.new{
		{1, 7, self.anim[1]},
		{8, 15, self.anim[2]},
		{16, 23, self.anim[3]},
		{24, 31, self.anim[4]},
		{32, 39, self.anim[3]},
		{40, 47, self.anim[2]}
	}

	self.Animation:setGotoAction(47, 1)
	self.Animation:play()
	
	self:setPosition(math.random(application:getLogicalWidth()), math.random(application:getLogicalHeight()))
	
	if createBody == true then
		-- [[ Create bird body for collision and set as sensor ]] --
		self.bird_body = world:createBody
		{
			type=b2.STATIC_BODY, 
			position = {x = math.random(application:getLogicalWidth()), y = math.random(application:getLogicalHeight())},
			fixedRotation = true,
			gravityScale = 0
		}
		self.bird_body.name = "bird"
		self.birdshape = b2.PolygonShape.new()
		self.birdshape:setAsBox(6,6)
		self.bird_body:createFixture
		{
			isSensor = true,
			shape = self.birdshape, 
			density = 1, 
			restituition = 0.0, 
			friction = 0.0 
		}
		self.body = self.bird_body
	end
	
	-- Add bird sprite ---
	self:addChild(self.Animation)

	-- Manage Events ---
	self:addEventListener(Event.ADDED_TO_STAGE, self.onAddedToStage, self)	
	self:addEventListener("stopevents", self.onRemovedFromStage, self)
	self:addEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
end

-----------------------------------
-- Add event when added to stage --
-----------------------------------
function birds:onAddedToStage()
	self:addEventListener(Event.ENTER_FRAME, self.onEnterFrame, self)
end

-------------------------------------------
-- Remove Events when removed from  stage --
-------------------------------------------
function birds:onRemovedFromStage()
  self:removeEventListener(Event.ENTER_FRAME, self.onEnterFrame, self)
  self:removeEventListener("stopevents", self.onRemovedFromStage, self)
  self:removeEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
end

--------------------------------------------------------------------------------------
-- [[ do "stupid" (only bounce on screen in random directions) logic of birds... ]] --
--------------------------------------------------------------------------------------
function birds:onEnterFrame(event)

	if self.bird_body then 
		x, y = self.bird_body:getPosition()
	else
		x, y = self:getPosition()
	end
	
	if x > application:getLogicalWidth()+32 then	
		self.xSpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*-1
		self.ySpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*self.randomDirection()
	elseif x < -32 then
		self.xSpeed = ((math.random(0, maxSpeed)/100))+minSpeed
		self.ySpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*self.randomDirection()
	end
	if y < -32 then
		self.xSpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*self.randomDirection()
		self.ySpeed = ((math.random(0, maxSpeed)/100)+minSpeed)
	elseif y > application:getLogicalHeight()+32 then
		self.xSpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*self.randomDirection()
		self.ySpeed = ((math.random(0, maxSpeed)/100)+minSpeed)*-1
	end
	
	x = x + (self.xSpeed * 100 * event.deltaTime)
	y = y + (self.ySpeed * 100 * event.deltaTime)
	
	if self.bird_body  then
		self.bird_body:setPosition(x, y)
	else
		self:setPosition(x,y)
	end
end