--[[

	---------------------------------------------
	GidHelix
	a simple game made to test and learn 
	Gideros SDK Power and Lua coding.
	
	Coded By Gianluca D'Angelo Copyright (C) 2012
	contact: gregbug@gmail.com
	THIS PROGRAM IS FREEWARE
	
	L'Aquila, 15 Gennaio 2012
	---------------------------------------------
	MODULE: Elichopter
	---------------------------------------------
	
--]]

-- elicopter Sprite Size...
local eliW 				= 28
local eliH 				= 35
local canExplode		= true
local eliSpeed			= 2

----------------
-- eli class ---
----------------
eli = gideros.class(Sprite)

---------------------------------------
-- Create a shape 	                 --
-- Taked from gideros chain example. --
---------------------------------------
local function createShape(w, h, color, alpha)
	local shape = Shape.new()
	shape:setFillStyle(Shape.SOLID, color, alpha)
	shape:beginPath()
		shape:moveTo(-w, -h)
		shape:lineTo(w, -h)
		shape:lineTo(w, h)
		shape:lineTo(-w, h)
		shape:closePath()
	shape:endPath()
	return shape
end

----------------------------------------------------------------------------
-- init elichopter class, load texture atlas... and setup physics data... --
----------------------------------------------------------------------------
function eli:init()
	self.timerBomb = Timer.new(172, 1)
	canExplode	= true
	eliSpeed 	= 2

-- setup animations...
	self.eliAnimFrames = {
		Bitmap.new(ingameGFX:getTextureRegion("eli1.png")),
		Bitmap.new(ingameGFX:getTextureRegion("eli2.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom1.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom2.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom3.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom4.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom5.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom6.png")),
		Bitmap.new(ingameGFX:getTextureRegion("boom7.png")),
		Bitmap.new(ingameGFX:getTextureRegion("elicontact1.png")),
		Bitmap.new(ingameGFX:getTextureRegion("elicontact2.png"))
	}
	
	eliAnimation = MovieClip.new{
		{1, 6, self.eliAnimFrames[1]},				-- Normal Speed animation frame 1
		{7, 13, self.eliAnimFrames[2]},				-- Normal Speed animation frame 2
		{15, 18, self.eliAnimFrames[1]},			-- FAST Speed animation frame 1
		{19, 22, self.eliAnimFrames[2]},			-- FAST Speed animation frame 1
		{23, 29, self.eliAnimFrames[10]},			-- Contact animation frames
		{30, 36, self.eliAnimFrames[11]},			-- Contact animation frames
		{37, 40, self.eliAnimFrames[3]},			-- EXPLOSION animation
		{41, 44, self.eliAnimFrames[4]},			-- EXPLOSION animation
		{45, 48, self.eliAnimFrames[5]},			-- EXPLOSION animation
		{49, 52, self.eliAnimFrames[6]},			-- EXPLOSION animation
		{55, 58, self.eliAnimFrames[7]},			-- EXPLOSION animation
		{61, 64, self.eliAnimFrames[8]},			-- EXPLOSION animation
		{65, 68, self.eliAnimFrames[9]}				-- EXPLOSION animation
	}
	
	eliAnimation:setGotoAction(13, 1)			-- Normal Speed Animation
	eliAnimation:setGotoAction(22, 15)			-- Fast Speed Animation
	eliAnimation:setGotoAction(36, 23)			-- Fast Speed Animation
	eliAnimation:setStopAction(68)
	
	--------------------------------------
	-- Create Elicopter
	--------------------------------------
	self.eli_body = world:createBody
	{
		type=b2.DYNAMIC_BODY, 
		position = {x = application:getLogicalWidth()/2, y = application:getLogicalHeight()/2-240},
		fixedRotation = false
	}

	self.eli_body.name = "eli"

	self.elishape = b2.PolygonShape.new()
	self.elishape:setAsBox(eliW/2, eliH/2, eliW/2, eliH/2, 0)
	
	self.eli_body:createFixture
	{
		shape = self.elishape, 
		density = 1, 
		restituition = 0.2, 
		friction = 0.3 
	}
	
	-- Attach sprite to body....
	self.body = self.eli_body
	
	--------------------------------------
	-- Create a chain under the elicopter
	--------------------------------------
	local chainShape = b2.PolygonShape.new()
		chainShape:setAsBox(.8, 3.8)
	local fd = {shape = chainShape, density = 20, friction = 0}
	
	local prevBody = self.eli_body
	local xChainPos = application:getLogicalWidth()/2+13.5
	local yChainPos = application:getLogicalHeight()/2-210
	
	for i=1,8 do
		-- make the chain
		local bd = {type = b2.DYNAMIC_BODY, position = {x = xChainPos, y = yChainPos+(i*7.5)}}
		local body = world:createBody(bd)
			body.name = "chain"
			body:createFixture(fd)
			
		local chainShape = createShape(.8, 3.8, 0xaaaaaa,0.6)
			body.shape = chainShape
			chainShape.body = body
			stage:addChild(chainShape)
	
		local jd = b2.createRevoluteJointDef(prevBody, body,  xChainPos, yChainPos+(i*7.0))
			jd.collideConnected = false
		local hook = world:createJoint(jd)
		
		if (i == 1) then
			eliHook = hook					-- Hook from eli and chain....
		end
		prevBody = body
	end
	
	-- make last ring of chain (magnet)
	local lastChainShape = b2.PolygonShape.new()
		lastChainShape:setAsBox(4, 3)
	local fd = {shape = lastChainShape, density = 20, friction = 0}
	local bd = {type = b2.DYNAMIC_BODY, position = {x = xChainPos, y = yChainPos+(9*7.4)}}
	local body = world:createBody(bd)
		body.name = "gancio"
		gancioBody = body
		body:createFixture(fd)
			
	local magnetShape = createShape(4, 3, 0xbb9988,0.6)
		body.shape = magnetShape
		magnetShape.body = body
		stage:addChild(magnetShape)
	
	local jd = b2.createRevoluteJointDef(prevBody, body,  xChainPos, yChainPos+(9*7.0))
		jd.collideConnected = false
		jd.enableLimit = true
		jd.lowerAngle =  0
		world:createJoint(jd)

	self:addChild(eliAnimation)
	eliAnimation:gotoAndPlay(1)
	
	-- Add events --
	self.timerBomb:addEventListener(Event.TIMER, self.onAfterExplosionAnimation)
	self:addEventListener(Event.ADDED_TO_STAGE, self.onAddedToStage, self)
	self:addEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
end

function eli:getEliXY()
	return self.eli_body:getPosition()
end
-----------------------------------
-- Add event when added to stage --
-----------------------------------
function eli:onAddedToStage()
	self:addEventListener(Event.ENTER_FRAME, self.onEnterFrame, self)
end
 
-------------------------------------------
-- Remove Event when removed from  stage --
-------------------------------------------
function eli:onRemovedFromStage()
	self:removeEventListener(Event.ENTER_FRAME, self.onEnterFrame, self)
	self.timerBomb:removeEventListener(Event.TIMER, self.onAfterExplosionAnimation)
	self:removeEventListener(Event.ADDED_TO_STAGE, self.onAddedToStage, self)
	self:removeEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
end

---------------------------
-- Start Explosion timer --
---------------------------
function eli:onAfterExplosionAnimation()
	if (eliHook) then
		world:destroyJoint(eliHook)
		stage:removeChild(elisprite)
	end
end

-----------------------------------
-- Play correct Animation of eli --
-----------------------------------
function eli:playEliAnimation(forceAnimationChange)
	-- change animation speed if needed...
	if not(eliBirdCollision) and  (oldEliSpeed ~= eliSpeed) or (forceAnimationChange) then
		if eliSpeed == 1 then
			eliAnimation:gotoAndPlay(1)
		else
			eliAnimation:gotoAndPlay(15)
		end
	end
end

-- do the logic of eli...
function eli:onEnterFrame(event)
	--fdt = event.deltaTime * lowfilter + fdt * (1 - lowfilter)
	-- Store last speed
	oldEliSpeed = eliSpeed
	-- store eli position...
	self.eli_px, self.eli_py = self.eli_body:getPosition()
	
	-- Move elicopter 
	local accelX = application:getAccelerometer()
		fx = accelX * 0.8
	
	local lvx, lvy = self.eli_body:getLinearVelocity() 
		self.eli_body:setLinearVelocity(fx*3, lvy)
--	fdt = event.deltaTime * filter + fdt * (1 - filter)

	--if player touch the screen powerup (only if not collision witrh birds) ..
	if (inTouch) and (eliBirdCollision == false) then
		self.eli_body:applyLinearImpulse(0, -52*fdt , self.eli_px+14, self.eli_py)
		eliSpeed = 2
	else
		-- else powerdown eli...
		self.eli_body:applyLinearImpulse(0, -38*fdt , self.eli_px+14, self.eli_py)
		eliSpeed = 1
	end
	
	-- Is Player alive ?
	if eliPower > eliDeath then
		self:playEliAnimation(false)
	else
		-- Is Death ?
		if canExplode then
			alarmPlayng = false
			sndSfxChannel   = sfx_eliExplosion:play()
			sndSfxChannel:setVolume(0.8)
			eliAnimation:gotoAndPlay(37)
			if sndClockChannel then 
				sndClockChannel:stop()
			end
			sndEliChannel:stop()
			sndEliAlarm:stop()
			self.timerBomb:start()
			canExplode = false
		end
	end
end

