--[[

	---------------------------------------------
	GidHelix
	a simple game made to test and learn 
	Gideros SDK Power and Lua coding.
	
	Coded By Gianluca D'Angelo Copyright (C) 2012
	contact: gregbug@gmail.com
	THIS PROGRAM IS FREEWARE
	
	L'Aquila, 15 Gennaio 2012
	---------------------------------------------
	MODULE: End Menu
	---------------------------------------------
	OK
--]]

--------------------
-- End Menu Class --
--------------------
CendMenu = gideros.class(Sprite)

function readBestScore()
	local bScore = 0
	local bLevel = 0 
	local file = io.open("|D|gidhelix_hiscores", "r")
	if (file) then
		bScore = file:read("*number") 
		bLevel = file:read("*number")
		file:close()
	end
	return bScore, bLevel
end
-------------------
-- Init End Menu --
-------------------
function CendMenu:init()
	local newRecord = false
	local bestScore = 0
	local bestLevel = 0
	local file = nil
	for j = sprGameOver:getNumChildren(), 1,-1 do
		sprGameOver:removeChildAt(j)
	end

	file = io.open("|D|gidhelix_hiscores", "r")
	
	if (file)	then
		-- Il file score esiste
		-- leggi il migior punteggio e chiudi il file
		bestScore = file:read("*number") 
		bestLevel = file:read("*number")
		file:close()
		-- il miglior punteggio è più alto di quello del giocatore =?
		if bestScore > PlayerScore then
			-- no record !!! :(
			newRecord = false
		else
			-- NUOVO RECORD !!! :)
			newRecord = true
			-- aggiorna il file records...
			local file = io.open("|D|gidhelix_hiscores", "w") 
			file:write(PlayerScore.." "..GameLevel)
			file:close()
			bestScore = PlayerScore
			bestLevel = GameLevel
		end
	else
		-- il file record non esiste allora crealo e metti il nuovo record...
		file = io.open("|D|gidhelix_hiscores", "w") 
		file:write(PlayerScore.." "..GameLevel)
		newRecord = true
		file:close()
		bestScore = PlayerScore
		bestLevel = GameLevel
	end
	
	
	-- [[ setup buttons... ]] --
	self.buttons = {
		Bitmap.new(btnTextGFX:getTextureRegion("mainmenu.png")),
		Bitmap.new(btnTextGFX:getTextureRegion("tryagain.png")),
	}
	endMenuSTAGE = Sprite.new()
	
	-- prepare gfx buttons
	self.mainMenu	= self.buttons[1]
	self.tryAgain	= self.buttons[2]
	
	-- Set mid Handle of GFX
	self.mainMenu:setAnchorPoint(0.5, 0.5)
	self.tryAgain:setAnchorPoint(0.5, 0.5)
	sprGameOver:setAnchorPoint(0.5, 0.5)
	
	-- Position Buttons
	self.mainMenu:setPosition(application:getLogicalWidth()/2, 80)
	self.tryAgain:setPosition(application:getLogicalWidth()/2, application:getLogicalHeight()-80)
	sprGameOver:setPosition(application:getLogicalWidth()/2, application:getLogicalHeight()-235)
	
	local line = TextField.new(font, "YOUR SCORE:"..PlayerScore.." at Level "..GameLevel)
	line:setPosition(-line:getWidth()/2,-10)
	line:setTextColor(0xFFFFFF)
	sprGameOver:addChild(line)


	if newRecord then
		bestLevel = GameLevel
		bestScore = PlayerScore
		local line = TextField.new(font3, "NEW HISCORE! ")
		local line2 = TextField.new(font3, PlayerScore)
		line:setPosition(-line:getWidth()/2, 30)
		line:setTextColor(0x33FF22)
		line2:setPosition(-line2:getWidth()/2, 70)
		line2:setTextColor(0x33FF22)
		sprGameOver:addChild(line)
		sprGameOver:addChild(line2)
	else
		local line = TextField.new(font, "BEST SCORE:"..bestScore.." at Level "..bestLevel)
		line:setPosition(-line:getWidth()/2, 10)
		line:setTextColor(0xFF6622)
		sprGameOver:addChild(line)
	end

	if sndEliChannel then
		sndEliChannel:stop()
	end

	if sndSFXChannel then
		sndSFXChannel:stop()
	end
	
	if sndEliAlarm then
		sndEliAlarm:stop()
	end
	
	if sndClockChannel then 
		sndClockChannel:stop()
	end

		
	-- Little fancy animations... 
	self.mainMenu:setScale(0,0)
	self.mainMenu:setAlpha(0.4)
	GTween.new(self.mainMenu, 1, {scaleX = 1.0, scaleY = 1.0, alpha = 1}, {ease = easing.outBounce})

	-- Little fancy animations... 
	self.tryAgain:setScale(0,0)
	self.mainMenu:setAlpha(0.4)
	GTween.new(self.tryAgain, 1.4, {scaleX = 1.0, scaleY = 1.0, alpha = 1}, {ease = easing.outBounce})

	sprGameOver:setScale(0,0)
	sprGameOver:setAlpha(0.4)
	GTween.new(sprGameOver, 1.2, {scaleX = 1.0, scaleY = 1.0, alpha = 1}, {ease = easing.outBounce})


	-- Add Sprites to Main Menu
	endMenuSTAGE:addChild(self.mainMenu)
	endMenuSTAGE:addChild(self.tryAgain)
	endMenuSTAGE:addChild(sprGameOver)
	stage:addChild(endMenuSTAGE)
	
	-- Manage Events ---
	self:addEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
	
	self.mainMenu:addEventListener(Event.MOUSE_DOWN, self.onMainMenu, self.mainMenu)
	self.tryAgain:addEventListener(Event.MOUSE_DOWN, self.onTryAgain, self.tryAgain)

end

--------------------------------------
-- Removed from stage remove events --
--------------------------------------
function CendMenu:onRemovedFromStage()
  self:removeEventListener(Event.MOUSE_DOWN, self.onMainMenu, self.mainMenu)
  self:removeEventListener(Event.MOUSE_DOWN, self.onTryAgain, self.onTryAgain)
  self:removeEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
end

-------------------------------------------
-- Player select to go back on main manu --
-------------------------------------------
function CendMenu:onMainMenu(event)
	if self:hitTestPoint(event.x, event.y)  then
		unloadEndMenu()
		musicChannel:stop()
		sndSfxChannel   = sfx_tap:play()
		sndSfxChannel:setVolume(0.8)
		collectgarbage()
		resetGameGlobalsToLevel_1()
		stage:addChild(CMainMenu.new())	
	end
end

------------------------------------------------------------------
-- Player select to replay this fantastic super hit game !!! ;) --
------------------------------------------------------------------
function CendMenu:onTryAgain(event)
	if self:hitTestPoint(event.x, event.y)  then
		sndSfxChannel   = sfx_tap:play()
		sndSfxChannel:setVolume(0.8)
		unloadEndMenu()
		RestartGame(true)
	end
end

-----------------------------------------------------------------
-- Unload end menu (remove sprite from stage end remove events --
-----------------------------------------------------------------
function unloadEndMenu()
	for j = stage:getNumChildren(), 1,-1 do
		stage:removeChildAt(j)
	end
end