--[[

	---------------------------------------------
	GidHelix
	a simple game made to test and learn 
	Gideros SDK Power and Lua coding.
	
	Coded By Gianluca D'Angelo Copyright (C) 2012
	contact: gregbug@gmail.com
	THIS PROGRAM IS FREEWARE
	
	L'Aquila, 15 Gennaio 2012
	---------------------------------------------
	MODULE: MAIN MENU
	---------------------------------------------
	OK
--]]

local mainMenuSTAGE		= nil																-- main menu screen
local howtoplayVisible 	= false																-- How to is Visible ?
local aboutVisible		= false																-- About is visible ?

CMainMenu = gideros.class(Sprite)															-- Main menu sprite class

-----------------------------
-- [[ compose Main menu ]] --
-----------------------------
function CMainMenu:setup_mainmenu()
	self.howtoplayVisible 	= false
	self.aboutVisible		= false
	-- prepare gfx buttons
	self.btnPlay	= self.mmbuttons[1]
	self.btnHowTo	= self.mmbuttons[2]
	self.btnAbout	= self.mmbuttons[3]
	
	-- Set mid Handle of GFX
	self.btnPlay:setAnchorPoint(0.5, 0.5)
	self.btnHowTo:setAnchorPoint(0.5, 0.5)
	self.btnAbout:setAnchorPoint(0.5, 0.5)
	
	-- Position Buttons
	self.btnPlay:setPosition(application:getLogicalWidth()/2, 130)
	self.btnHowTo:setPosition(application:getLogicalWidth()/2, 200)
	self.btnAbout:setPosition(application:getLogicalWidth()/2, 270)
	


	-- Add Sprites to Main Menu
	mainMenuSTAGE:addChild(bgMainMenu)
	mainMenuSTAGE:addChild(self.btnPlay)
	mainMenuSTAGE:addChild(self.btnHowTo)
	mainMenuSTAGE:addChild(self.btnAbout)

	local bScore, bLevel = readBestScore()
	local txtlevel = TextField.new(font2, "Hi-Score "..bScore.." at level "..bLevel)
	txtlevel:setPosition(application:getLogicalWidth()/2-txtlevel:getWidth()/2, 320)
	txtlevel:setTextColor(0x66AAff)
	mainMenuSTAGE:addChild(txtlevel)
	
	-- add birs...
	for i= 1,10 do
		mainMenuSTAGE:addChild(birds.new(false))
	end	

	stage:addChild(mainMenuSTAGE)
	

	
end

------------------------------------
-- [[ remove Main menu sprites ]] --
------------------------------------
function unloadMainMenuSTAGE(Event)
	for j = stage:getNumChildren(), 1,-1 do
		stage:removeChildAt(j)
	end
end

-----------------------------------------
-- [[ init main menu gfx and events ]] --
-----------------------------------------
function CMainMenu:init()
	self.buttonAngle = math.random(0, 50)
	self.onTween = false
	
	self.mmbuttons = {
		Bitmap.new(btnTextGFX:getTextureRegion("play.png")),			-- Play Button GFX
		Bitmap.new(btnTextGFX:getTextureRegion("howto.png")),			-- HowTo Button GFX
		Bitmap.new(btnTextGFX:getTextureRegion("about.png"))			-- About Button GFX
	}	
	mainMenuSTAGE = Sprite.new()
	self:setup_mainmenu()

	-- start Music
	
	musicChannel = mus_menumusic:play(0, 10000)
	musicChannel:setVolume(0.4)
	
	-- Add events...
	self:addEventListener(Event.ADDED_TO_STAGE, self.onAddedToStage, self)
	self:addEventListener(Event.REMOVED_FROM_STAGE, self.onRemovedFromStage, self)
	-- Button Events
	self.btnPlay:addEventListener(Event.MOUSE_DOWN, self.onPlayClick, self.btnPlay)
	self.btnHowTo:addEventListener(Event.MOUSE_DOWN, self.onHowToClick, self.btnHowTo)
	self.btnAbout:addEventListener(Event.MOUSE_DOWN, self.onAboutClick, self.btnAbout)
end

-----------------------------------------------------
-- Register event listner when added to the stage ---
-----------------------------------------------------
function CMainMenu:onAddedToStage()
  self:addEventListener(Event.ENTER_FRAME, self.onEnterFrame_mainMenu, self)
end
 
----------------------------------------------------
-- UnRegister events when removed from the stage ---
----------------------------------------------------
function CMainMenu:onRemovedFromStage()
  self:removeEventListener(Event.ENTER_FRAME, self.onEnterFrame_mainMenu,self)
  self.btnPlay:removeEventListener(Event.MOUSE_DOWN, self.onPlayClick, self.btnPlay)
  self.btnHowTo:removeEventListener(Event.MOUSE_DOWN, self.onHowToClick, self.btnHowTo)
  self.btnAbout:removeEventListener(Event.MOUSE_DOWN, self.onAboutClick, self.btnAbout)
end
--------------------------------
-- [[ main menu logic loop ]] --
--------------------------------
function CMainMenu:onEnterFrame_mainMenu(event)
	local newAngle = math.sin(self.buttonAngle)*6
	
	self.btnPlay:setRotation(newAngle)
	self.btnHowTo:setRotation(newAngle)
	self.btnAbout:setRotation(newAngle)
	
	self.btnPlay:setScale(1+(newAngle/25), 1+(newAngle/40))
	self.btnHowTo:setScale(1+(newAngle/70), 1+(newAngle/60))
	self.btnAbout:setScale(1+(newAngle/30), 1+(newAngle/60))
	
	self.buttonAngle = self.buttonAngle + (5*event.deltaTime)
	--print("DEBUG: - MainMenu onEnterFrame",os.timer())
end
 
------------------------------
-- [[ user selected play ]] --
------------------------------
function CMainMenu:onPlayClick(event)
	if self:hitTestPoint(event.x, event.y)  then
		sndSfxChannel   = sfx_tap:play()
		sndSfxChannel:setVolume(1)
		unloadMainMenuSTAGE()
		-- start Music
		musicChannel:stop()
		resetGameGlobalsToLevel_1()
		stage:addChild(cShowLevel.new())
	end
end

--------------------------------
--[[  user selected How to  --]]
--------------------------------
function CMainMenu:onHowToClick(event)
	local function removeHowTo(tween)
		if sprHowto then	
			mainMenuSTAGE:removeChild(sprHowto)
			self.onTween = false
		end
	end
	local function tweenInEnd(tween)
		self.onTween = false
	end
	if not(self.onTween) then
		if (not howtoplayVisible) then
			if self:hitTestPoint(event.x, event.y) then
				sndSfxChannel   = sfx_tap:play()
				sndSfxChannel:setVolume(1)
				howtoplayVisible = not howtoplayVisible
				sprHowto:setAnchorPoint(0.5, 0.5)
				sprHowto:setPosition(application:getLogicalWidth()/2,application:getLogicalHeight()/2)
				sprHowto:setScale(0,0)
				GTween.new(sprHowto, 0.8, {scaleX = 1.0, scaleY = 1.0}, {ease = easing.outBounce, onComplete=tweenInEnd})
				self.onTween = true
				mainMenuSTAGE:addChild(sprHowto)
				event:stopPropagation()
			end
		else
			sndSfxChannel   = sfx_tap:play()
			sndSfxChannel:setVolume(1)
			howtoplayVisible = not howtoplayVisible
			GTween.new(sprHowto, 0.6, {scaleX = 0.0, scaleY = 0.0}, {ease = easing.inBack, onComplete=removeHowTo})
			self.onTween = true	
			event:stopPropagation()
		end
	end
end


-------------------------------
--[[  user selected About  --]]
-------------------------------
function CMainMenu:onAboutClick(event)
	local function removeAbout(tween)
		if sprAbout then	
			mainMenuSTAGE:removeChild(sprAbout)
			self.onTween = false
		end
	end
	local function tweenInEnd(tween)
		self.onTween = false
	end
	if not(self.onTween) then
		if (not howtoplayVisible) then
			if (not aboutVisible) then
				if self:hitTestPoint(event.x, event.y) then
					sndSfxChannel   = sfx_tap:play()
					sndSfxChannel:setVolume(1)
					aboutVisible = not aboutVisible
					sprAbout:setAnchorPoint(0.5, 0.5)
					sprAbout:setPosition(application:getLogicalWidth()/2,application:getLogicalHeight()/2)
					sprAbout:setScale(0,0)
					GTween.new(sprAbout, 0.8, {scaleX = 1.0, scaleY = 1.0}, {ease = easing.outBounce, onComplete=tweenInEnd})
					self.onTween = true
					mainMenuSTAGE:addChild(sprAbout)
					event:stopPropagation()
				end
			else
				aboutVisible = not aboutVisible
				sndSfxChannel   = sfx_tap:play()
				sndSfxChannel:setVolume(1)
				GTween.new(sprAbout, 0.6, {scaleX = 0.0, scaleY = 0.0},  {ease = easing.inBack, onComplete=removeAbout})
				self.onTween = true
				event:stopPropagation()
			end
		end
	end
end